#ifndef QT_FEATURES_WebView_src_webview_qtwebview_config_h_H
#define QT_FEATURES_WebView_src_webview_qtwebview_config_h_H

#define QT_FEATURE_webview_webview2_plugin -1

#define QT_FEATURE_webview_webengine_plugin 1

#define QT_FEATURE_webview_android_plugin -1

#define QT_FEATURE_webview_darwin_plugin -1

#define QT_FEATURE_webview_wasm_plugin -1


#endif // QT_FEATURES_WebView_src_webview_qtwebview_config_h_H
